@@ -10,7 +10,6 @@ python -m 'rpy2.tests'
 
 from dsc.utils import flatten_list
 
-
 def load_mpk(mpk_files, jobs=2):
     import msgpack, collections
     from multiprocessing import Process, Manager
@@ -245,7 +244,6 @@ def symlink_force(target, link_name):
         else:
             raise e
 
-
 def csv_to_html(infile, outfile):
     import os
     import pandas as pd
@@ -271,6 +269,24 @@ def csv_to_html(infile, outfile):
     with open(outfile, 'w') as f:
         f.write(TABLE_HEADER + data.to_html(justify='center', escape=False))
 
+def source_dirs(dirs):
+    import sys, os, glob
+    reserved = ['__builtins__', '__cached__', '__doc__', '__file__', '__loader__', '__name__', '__package__', '__spec__']
+    functions = list()
+    for item in dirs:
+        item = os.path.abspath(os.path.expanduser(item))
+        sys.path.append(item)
+        for module in glob.glob(f'{item}/*.py'):
+            m = __import__(os.path.basename(module)[:-3])
+            for i in dir(m):
+                if not i in reserved:
+                    functions.append((i, getattr(m,i)))
+    return functions
+
+def load_io_db(fn, sequence_id=None, module=None):
+    import pickle
+    data = pickle.load(open(fn, 'rb'))
+    return data[sequence_id][module] if sequence_id and module else data
 
 def main():
     import os, sys, pickle
@@ -301,4 +317,4 @@ if __name__ == '__main__':
     from rpy2.rinterface import RRuntimeWarning
     with warnings.catch_warnings():
         warnings.filterwarnings("ignore", category=RRuntimeWarning)
-        main()
+        main()
\ No newline at end of file
