@@ -6,7 +6,7 @@ __license__ = "MIT"
 '''
 This file defines methods to translate DSC into pipeline in SoS language
 '''
-import os, sys, msgpack, glob, inspect
+import os, sys, pickle, glob, inspect
 try:
     from xxhash import xxh32 as xxh
 except ImportError:
@@ -14,7 +14,8 @@ except ImportError:
 from collections import OrderedDict
 from sos.targets import path
 from sos import execute_workflow
-from .utils import uniq_list, dict2str, n2a, load_io_db, install_package
+from .utils import uniq_list, dict2str, n2a, install_package
+from .dsc_io import load_io_db
 from .syntax import DSC_CACHE
 __all__ = ['DSC_Translator']
 
@@ -42,7 +43,7 @@ class DSC_Translator:
                         host_conf[kk] = host_conf[k]
                     del host_conf[k]
         conf_header = 'import os\nfrom dsc.dsc_database import build_config_db, ResultDB\n'
-        job_header = f"[global]\nimport os\n\nIO_DB = '{self.output}/{self.db}.conf.mpk'\n\n"\
+        job_header = f"[global]\nimport os\n\nIO_DB = '{DSC_CACHE}/{self.db}.io.pkl'\n\n"\
                      f"{inspect.getsource(load_io_db)}"
         processed_steps = dict()
         self.depends = dict()
@@ -78,7 +79,6 @@ class DSC_Translator:
                         job_translator = self.Step_Translator(
                             step, self.db, None, try_catch, host_conf, debug)
                         job_str.append(job_translator.dump())
-                        job_translator.clean()
                         exe_signatures[
                             step.name] = job_translator.exe_signature
                         self.exe_check.extend(job_translator.exe_check)
@@ -113,12 +113,12 @@ class DSC_Translator:
             # Configuration
             if len(new_steps):
                 conf_str.append(f"###\n# [{n2a(workflow_id + 1)}]\n###\n" \
-                                f"__pipeline_id__ = '{workflow_id + 1}'\n"\
+                                f"__pipeline_id__ = {workflow_id + 1}\n"\
                                 f'''__pipeline_name__ = '{"+".join([n2a(x[1]).lower()+"_"+x[0] for x in sqn])}'\n''' \
-                                f"# output: '{DSC_CACHE}/{self.db}_{workflow_id + 1}.mpk'\n")
+                                f"# output: '{DSC_CACHE}/{self.db}_{workflow_id + 1}.pkl'\n")
                 conf_str.extend(new_steps)
                 io_info_files.append(
-                    f'{DSC_CACHE}/{self.db}_{workflow_id + 1}.mpk')
+                    f'{DSC_CACHE}/{self.db}_{workflow_id + 1}.pkl')
             # Execution pool
             ii = 1
             for y in sequence:
@@ -136,31 +136,31 @@ class DSC_Translator:
                     self.last_steps.append((y, workflow_id + 1))
                 self.job_pool[(y, workflow_id + 1)] = tmp_str
                 ii += 1
-        conf_str_py = 'import msgpack\nfrom collections import OrderedDict\n' + \
+        conf_str_py = 'import pickle\nfrom collections import OrderedDict\n' + \
                       'from dsc.utils import sos_hash_output, sos_group_input, chunks as sos_chunks\n' + \
                       '\n'.join([f'## {x}' for x in dict2str(self.step_map).split('\n')]) + \
                       '@profile #via "kernprof -l" and "python -m line_profiler"\ndef prepare_io():\n\t'+ \
                       f'\n\t__io_db__ = OrderedDict()\n\t' + \
                       '\n\t'.join('\n'.join(conf_str).split('\n')) + \
-                      f"\n\topen('{DSC_CACHE}/{self.db}.io.mpk', 'wb').write(msgpack.packb(__io_db__))\n\n" + \
+                      f"\n\tpickle.dump(__io_db__, open('{DSC_CACHE}/{self.db}.cfg.pkl', 'wb'))\n\n" + \
                       "if __name__ == '__main__':\n\tprepare_io()"
         self.job_str = job_header + "\n{}".format('\n'.join(job_str))
         self.conf_str_sos = conf_header + \
                             "\n[deploy_1 (Hashing output files)]" + \
                             (f'\ndepends: {", ".join(uniq_list(self.exe_check))}' if len(self.exe_check) and host_conf is None else '') + \
-                            f"\noutput: '{DSC_CACHE}/{self.db}.io.mpk'" + \
+                            f"\noutput: '{DSC_CACHE}/{self.db}.cfg.pkl'" + \
                             "\nscript: interpreter={}, suffix='.py'\n{}\n".\
                             format(f'{path(sys.executable):er}',
                                    '\n'.join(['\t' + x for x in conf_str_py.split('\n')])) + \
                             "\n[deploy_2 (Configuring output filenames)]\n"\
                             f"parameter: vanilla = {rerun}\n"\
                             f"output: '{self.output}/{self.db}.map.mpk', "\
-                            f"'{self.output}/{self.db}.conf.mpk'"\
+                            f"'{DSC_CACHE}/{self.db}.io.pkl'"\
                             "\nbuild_config_db(str(_input[0]), str(_output[0]), "\
                             f"str(_output[1]), vanilla = vanilla, jobs = {n_cpu})\n"\
                             f"if os.path.isfile('{self.output}/{self.db}.db'): os.remove('{self.output}/{self.db}.db')\n"\
                             "\n[build (Build meta-database)]\n"\
-                            f"depends: '{DSC_CACHE}/{self.db}.io.mpk', '{self.output}/{self.db}.map.mpk'\n"\
+                            f"depends: '{DSC_CACHE}/{self.db}.cfg.pkl', '{self.output}/{self.db}.map.mpk'\n"\
                             f"output: '{self.output}/{self.db}.db'"\
                             "\nResultDB(f'{_output:n}')."\
                             f"Build(script = open('{runtime.output}.html').read(), groups = {runtime.groups}, depends = {self.get_dependency()}, pipelines = {runtime.sequence})"
@@ -174,13 +174,9 @@ class DSC_Translator:
     def get_pipeline(self, task, save=False):
         if task == 'prepare':
             res = self.conf_str_sos
-            open(f'{DSC_CACHE}/{self.db}.io.meta.mpk',
-                 'wb').write(msgpack.packb(self.step_map))
+            pickle.dump(self.step_map, open(f'{DSC_CACHE}/{self.db}.io.meta.pkl', 'wb'))
         else:
             res = self.job_str
-        # clean up previous runs
-        if os.path.isfile('.sos/transcript.txt'):
-            os.remove('.sos/transcript.txt')
         # write explicit SoS script if desired
         if save:
             output = os.path.abspath(f'{DSC_CACHE}/{self.db}_{task}.sos')
@@ -190,7 +186,7 @@ class DSC_Translator:
 
     def filter_execution(self, debug=False):
         '''Filter steps removing the ones having common input and output'''
-        io_db = load_io_db(f'{self.output}/{self.db}.conf.mpk')
+        io_db = load_io_db(f'{DSC_CACHE}/{self.db}.io.pkl')
         included_steps = []
         for x in self.job_pool:
             if self.step_map[x[1]][x[0]] == x:
@@ -270,9 +266,7 @@ class DSC_Translator:
             '''
             prepare step:
              - will produce source to build config and database for
-            parameters and file names. The result is one binary json file (via msgpack)
-            with keys "X:Y:Z" where X = DSC sequence ID, Y = DSC subsequence ID, Z = DSC step name
-                (name of indexed DSC block corresponding to a computational routine).
+            parameters and file names. The result is a dictionary (key-value database) saved in pickle
             run step:
              - will construct the actual script to run
             '''
@@ -308,11 +302,6 @@ class DSC_Translator:
             self.get_step_option()
             self.get_action()
 
-        def clean(self):
-            # Remove temp scripts
-            for item in glob.glob(f'.sos/{self.step.name}_*'):
-                os.remove(item)
-
         def get_header(self):
             if self.prepare:
                 self.header = f"## Codes for {self.step.name}\n"
@@ -416,9 +405,9 @@ class DSC_Translator:
                     len(self.step.exe['path']) == 0
                     and len(self.step.rv) > 0) else 'yml'
                 if len(self.current_depends):
-                    self.action += f"__io_db__['{self.step.name}:' + str(__pipeline_id__)] = dict([(' '.join((y, x[1])), dict([('__pipeline_id__', __pipeline_id__), ('__pipeline_name__', __pipeline_name__), ('__module__', '{self.step.name}'), ('__out_vars__', __out_vars__)] + x[0])) for x, y in zip({combined_params}, {output_str})] + [('__input_output___', ({input_str}, {output_str})), ('__ext__', '{ext_str}')])\n"
+                    self.action += f"__io_db__[('{self.step.name}', __pipeline_id__)] = dict([(tuple(' '.join((y, x[1])).split()), dict([('__pipeline_id__', __pipeline_id__), ('__pipeline_name__', __pipeline_name__), ('__module__', '{self.step.name}'), ('__out_vars__', __out_vars__)] + x[0])) for x, y in zip({combined_params}, {output_str})] + [('__input_output___', ({input_str}, {output_str})), ('__ext__', '{ext_str}')])\n"
                 else:
-                    self.action += f"__io_db__['{self.step.name}:' + str(__pipeline_id__)] = dict([(y, dict([('__pipeline_id__', __pipeline_id__), ('__pipeline_name__', __pipeline_name__), ('__module__', '{self.step.name}'), ('__out_vars__', __out_vars__)] + x[0])) for x, y in zip({combined_params}, {output_str})] + [('__input_output___', ({input_str}, {output_str})), ('__ext__', '{ext_str}')])\n"
+                    self.action += f"__io_db__[('{self.step.name}', __pipeline_id__)] = dict([((y,), dict([('__pipeline_id__', __pipeline_id__), ('__pipeline_name__', __pipeline_name__), ('__module__', '{self.step.name}'), ('__out_vars__', __out_vars__)] + x[0])) for x, y in zip({combined_params}, {output_str})] + [('__input_output___', ({input_str}, {output_str})), ('__ext__', '{ext_str}')])\n"
             else:
                 # FIXME: have not considered multi-action module (or compound module) yet
                 # Create fake loop for now with idx going around
