@@ -6,7 +6,7 @@ __license__ = "MIT"
 '''
 Process R and Python plugin codes to DSC
 '''
-import yaml, re
+import yaml, re, glob
 from collections import OrderedDict
 from copy import deepcopy
 from .syntax import DSC_FILE_OP
@@ -14,8 +14,7 @@ from .utils import flatten_list
 
 
 def dict2yaml(value):
-    return yaml.dump(value, default_flow_style=False).strip()
-
+    return yaml.safe_dump(dict(value), default_flow_style=False).strip()
 
 BASH_UTILS = '''
 expandPath() {
@@ -129,6 +128,7 @@ class Shell(BasePlug):
         if len(lib):
             res += '\n'.join([
                 f'for i in `ls {item}/*.sh`; do source $i; done'
+                if len(glob.glob(f'{item}/*.sh'))>0 else ''
                 for item in lib
             ])
         # load parameters
@@ -508,7 +508,7 @@ class PyPlug(BasePlug):
             if x[1] is not None
         ])]
         # load files
-        res += '\nfrom dsc.dsc_io import load_dsc as __load_dsc__'
+        res += '\nfrom dsc.dsc_io import load_dsc as __load_dsc__, source_dirs as __source_dirs__'
         load_in = f'\n{self.identifier} = __load_dsc__([${{paths([_input[i] for i in {load_idx}]):r,}}])'
         assign_in = ['\n']
         for i, k in assign_idx:
@@ -541,8 +541,11 @@ class PyPlug(BasePlug):
         return res
 
     def get_input(self, params, lib, seed_option):
-        res = '\n'.join(
-            [f'sys.path.append(os.path.expanduser("{item}"))' for item in lib])
+        # import from lib_path
+        res = '__source_dirs__([{}])'.format(','.join(
+            [repr(x) for x in lib])) if len(lib) else ''
+        res = f'for name, func in {res}:\n'
+        res += '    globals()[name] = func'
         # load parameters
         keys = [x for x in params if not x in self.container_vars]
         res += '\n' + '\n'.join(self.container)
@@ -553,7 +556,7 @@ class PyPlug(BasePlug):
             res += '\nDSC_SEED = DSC_REPLICATE'
         else:
             res += '\nDSC_SEED += DSC_REPLICATE'
-        res += '\nimport random\nrandom.seed(DSC_SEED)\ntry:\n\timport numpy; numpy.random.seed(DSC_SEED)\nexcept Exception:\n\tpass'
+        res += '\nimport random\nrandom.seed(DSC_SEED)\ntry:\n\timport numpy\n\tnumpy.random.seed(DSC_SEED)\nexcept Exception:\n\tpass'
         return res
 
     def get_output(self, params):
